Perform various style checks related to placement and spacing of curly braces:
brace_linter(allow_single_line = FALSE)if TRUE, allow an open and closed curly pair on the same line.
configurable, default, readability, style
Opening curly braces are never on their own line and are always followed by a newline.
Opening curly braces have a space before them.
Closing curly braces are on their own line unless they are followed by an else.
Closing curly braces in if conditions are on the same line as the corresponding else.
Either both or neither branch in if/else use curly braces, i.e., either both branches use {...} or neither
does.
Functions spanning multiple lines use curly braces.
linters for a complete list of linters available in lintr.
https://style.tidyverse.org/syntax.html#indenting
https://style.tidyverse.org/syntax.html#if-statements