powered by
Check that all left parentheses have a space before them unless they are in a function call.
spaces_left_parentheses_linter()
default, readability, style
linters for a complete list of linters available in lintr. https://style.tidyverse.org/syntax.html#parentheses