testthat::expect_gt(), testthat::expect_gte(), testthat::expect_lt(),
testthat::expect_lte(), and testthat::expect_equal() exist specifically
for testing comparisons between two objects. testthat::expect_true() can
also be used for such tests, but it is better to use the tailored function
instead.
expect_comparison_linter()best_practices, package_development
linters for a complete list of linters available in lintr.