Check that infix operators are surrounded by spaces. Enforces the corresponding Tidyverse style guide rule; see https://style.tidyverse.org/syntax.html#infix-operators.
infix_spaces_linter(exclude_operators = NULL, allow_multiple_spaces = TRUE)Character vector of operators to exlude from consideration for linting.
Default is to include the following "low-precedence" operators:
+, -, ~, >, >=, <, <=, ==, !=, &, &&, |, ||, <-, :=, <<-, ->, ->>,
=, /, *, and any infix operator (exclude infixes by passing "%%"). Note that <-, :=, and <<-
are included/excluded as a group (indicated by passing "<-"), as are -> and ->> (viz, "->"),
and that = for assignment and for setting arguments in calls are treated the same.
Logical, default TRUE. If FALSE, usage like x = 2 will also be linted;
excluded by default because such usage can sometimes be used for better code alignment, as is allowed
by the style guide.
default, readability, style
linters for a complete list of linters available in lintr.
https://style.tidyverse.org/syntax.html#infix-operators