Check for missing packages and symbols in namespace calls.
Note that using check_exports=TRUE or check_nonexports=TRUE will load packages used in user code so it could
potentially change the global state.
namespace_linter(check_exports = TRUE, check_nonexports = TRUE)Check if symbol is exported from namespace in namespace::symbol calls.
Check if symbol exists in namespace in namespace:::symbol calls.
configurable, correctness, executing, robustness
linters for a complete list of linters available in lintr.