| print_linter | R Documentation |
The default print method for character vectors is appropriate for interactively inspecting objects,
not for logging messages. Thus checked-in usage like print(paste('Data has', nrow(DF), 'rows.'))
is better served by using cat(), e.g. cat(sprintf('Data has %d rows.\n', nrow(DF))). Note that
using cat() entails supplying your own line returns; glue::glue() might be preferable
to sprintf() for constructing templated strings. Alternatively, writeLines() can be used to
print character vectors with their own line returns. Lastly, note that message() differs slightly
from cat() in that it prints to stderr by default, not stdout, but is still a good option
to consider for logging purposes.
print_linter()
best_practices, consistency
linters for a complete list of linters available in lintr.
# will produce lints
lint(
text = "print('a')",
linters = print_linter()
)
lint(
text = "print(paste(x, 'y'))",
linters = print_linter()
)
# okay
lint(
text = "print(x)",
linters = print_linter()
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.