Report the use of undesirable operators, e.g. ::: or
<<- and suggest an alternative.
undesirable_operator_linter(op = default_undesirable_operators)Named character vector. names(op) correspond to undesirable operators,
while the values give a description of why the operator is undesirable.
If NA, no additional information is given in the lint message. Defaults to
default_undesirable_operators. To make small customizations to this list,
use modify_defaults().
best_practices, configurable, efficiency, robustness, style
linters for a complete list of linters available in lintr.