Check that imported packages are actually used
unused_import_linter(
allow_ns_usage = FALSE,
except_packages = c("bit64", "data.table", "tidyverse")
)Suppress lints for packages only used via namespace.
This is FALSE by default because pkg::fun() doesn't require library(pkg).
You can use requireNamespace("pkg") to ensure a package is installed without loading it.
Character vector of packages that are ignored. These are usually attached for their side effects.
best_practices, common_mistakes, configurable, executing
linters for a complete list of linters available in lintr.