Yoda tests use (expected, actual) instead of the more common (actual, expected).
This is not always possible to detect statically; this linter focuses on
the simple case of testing an expression against a literal value, e.g.
(1L, foo(x)) should be (foo(x), 1L).
yoda_test_linter()best_practices, package_development, readability
linters for a complete list of linters available in lintr. https://en.wikipedia.org/wiki/Yoda_conditions